@@ -145,7 +145,6 @@ impl Vecu8 for &[u8] {
 }
 
 impl VecVecu8 for &[Vec<u8>] {
-
     fn acentroid(self) -> Vec<f64> {
     let mut centre = vec![0_f64; self[0].len()];
     for v in self {
@@ -155,44 +154,46 @@ impl VecVecu8 for &[Vec<u8>] {
     centre
     }
 
-    /// Eccentricity vector for a non member point.
-    /// The true geometric median is as yet unknown.
-    /// Returns the eccentricity vector.
-    /// The true geometric median would return zero vector.
-   fn eccnonmember(self, p:&[f64]) -> Vec<f64> {
+    /// Eccentricity vector added to a non member point,
+    /// while the true geometric median is as yet unknown. 
+    /// This function is suitable for a single non-member point. 
+    fn nxnonmember(self, p:&[f64]) -> Vec<f64> {
         let mut vsum = vec![0_f64; self[0].len()];
         let mut recip = 0_f64;
         for x in self { 
-            let dvmag = x.vdist(&p);
+            let dvmag = x.vdist(p);
             if !dvmag.is_normal() { continue } // zero distance, safe to ignore
             let rec = 1.0/dvmag;
-            vsum.mutvadd(&x.smult(rec)); // add unit vector
+            vsum.mutvadd(&x.smult(rec)); // add vector
             recip += rec // add separately the reciprocals    
         }
         vsum.mutsmult(1.0/recip);
-        vsum.vsub(&p)
+        vsum
     }
+
     /// Secant method with recovery from divergence
-    /// for finding the geometric median of vectors of vectors of bytes
+    /// for finding the geometric median
     fn gmedian(self, eps: f64) -> Vec<f64> {
         let mut p1 = self.acentroid();     
-        let e1 = self.eccnonmember(&p1); // eccentricity vector1 
-        let mut e1mag = e1.vmag(); 
-        let mut p2 = p1.vadd(&e1);   
+        let mut p2 = self.nxnonmember(&p1); 
+        let mut e1mag = p2.vdist(&p1);    
         loop {
-            let e2 = self.eccnonmember(&p2); // eccentricity vector2
+            // will not use this np as does nmedian, using secant instead
+            let mut np = self.nxnonmember(&p2); 
+            let e2 = np.vsub(&p2); // new vetor error, or eccentricity
             let e2mag = e2.vmag(); 
-            if e2mag < eps  { return p2 }; 
-            let newp;         
+            if e2mag < eps  { return np };  
             if e1mag > e2mag {  // eccentricity magnitude decreased, good, employ secant
-                newp = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag-e2mag)))                   
+                np = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag-e2mag)));                   
             }
-            else { // probably overshot the minimum, go nearer, back 
-               newp = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag+e2mag)))                    
+            else { // recovery: probably overshot the minimum, shorten the jump 
+                   // e2 will already be pointing moreless back
+                np = p2.vadd(&e2.smult(p1.vsub(&p2).vmag()/(e1mag+e2mag)));                    
             } 
             p1 = p2;        
-            p2 = newp;  
+            p2 = np;  
             e1mag = e2mag             
         }       
-    }    
+    }
+
 }
\ No newline at end of file
